@@ -1,3 +1,4 @@
+import logging
 import re
 import tempfile
 from datetime import timedelta
@@ -9,6 +10,9 @@ from django.utils.functional import lazy
 import xml.dom.minidom
 
 
+logger = logging.getLogger(__name__)
+
+
 def format_full_name(first_name: str, last_name: str, max_length: int = 20):
     """
     Limits name length to specified length. Tries to keep name as human-readable an natural as possible.
@@ -95,11 +99,12 @@ def format_xml(content: str or bytes, encoding: str = 'UTF-8', exceptions: bool
                 fp.write(content)
                 fp.flush()
                 out = subprocess.check_output([settings.XMLLINT_PATH, '--format', fp.name])
-                return out.decode()
+                return out.decode(encoding=encoding)
         if isinstance(content, bytes):
             content = content.decode(encoding=encoding)
         return xml.dom.minidom.parseString(content).toprettyxml()
-    except Exception:
+    except Exception as e:
+        logger.error('format_xml failed: %s', e)
         if exceptions:
             raise
         return content.decode(encoding=encoding) if isinstance(content, bytes) else content
@@ -126,7 +131,8 @@ def format_xml_bytes(content: str or bytes, encoding: str = 'UTF-8', exceptions:
         if isinstance(content, bytes):
             content = content.decode(encoding=encoding)
         return xml.dom.minidom.parseString(content).toprettyxml(encoding=encoding)
-    except Exception:
+    except Exception as e:
+        logger.error('format_xml_bytes failed: %s', e)
         if exceptions:
             raise
         return content.encode(encoding=encoding) if isinstance(content, str) else content
@@ -148,14 +154,15 @@ def format_xml_file(full_path: str, encoding: str = 'UTF-8', exceptions: bool =
             return subprocess.check_output([settings.XMLLINT_PATH, '--format', full_path])
         with open(full_path, 'rb') as fp:
             return xml.dom.minidom.parse(fp).toprettyxml(encoding=encoding)
-    except Exception:
+    except Exception as e:
+        logger.error('format_xml_file failed (1): %s', e)
         if exceptions:
             raise
     try:
         with open(full_path, 'rb') as fp:
             return fp.read()
-    except Exception:
-        pass
+    except Exception as e:
+        logger.error('format_xml_file failed (2): %s', e)
     return b''
 
 
